@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 # -*- coding: utf-8 -*-
 #
 # (c) Copyright 2003-2008 Hewlett-Packard Development Company, L.P.
@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 #
-# Author: Don Welch
+# Author: Don Welch, Naga Samrat Chowdary Narla,
 
 # Local
 from base.g import *
@@ -101,6 +101,7 @@ TECH_CLASSES = [
     "Pyramid",
     "Python10",
     "Mimas",
+    "StingrayOJ",
 ]
 
 TECH_CLASSES.sort()
@@ -153,6 +154,7 @@ TECH_CLASS_PDLS = {
     "OJ7000"        : 'pcl3',
     "Python10"      : 'pcl3',
     "Mimas"      : 'pcl3',
+    "StingrayOJ"   : 'pcl3',
 }
 
 PDL_TYPE_PCL = 0  # less preferred
@@ -205,6 +207,7 @@ TECH_SUBCLASSES = [
     "SmallMargins",
     "Trim",
     "4800x1200dpi",
+    "Advanced",
 ]
 
 TECH_SUBCLASSES.sort()
@@ -300,7 +303,6 @@ class ModelData:
             'scan-style' : TYPE_INT,
             'scan-type' : TYPE_INT,
             'scan-src' : TYPE_INT,
-            'scan-color' : TYPE_INT,
             #'scan-duplex' : TYPE_BOOL,
             'status-battery-check' : TYPE_INT,
             'status-dynamic-counters' : TYPE_INT,
@@ -315,6 +317,7 @@ class ModelData:
             'usb-pid' : TYPE_HEX,
             'usb-vid' : TYPE_HEX,
             'wifi-config': TYPE_INT,
+            'ppd-name' : TYPE_STR,
             }
 
         self.FIELD_TYPES_DYN = {
