@@ -65,8 +65,8 @@ def addgroup():
         fp=open('/etc/cups/cupsd.conf')
     except IOError:
         try:
-            if "root" != grp.getgrgid(os.stat('/etc/cups/cupsd.conf').st_gid)[0]:
-                return grp.getgrgid(os.stat('/etc/cups/cupsd.conf').st_gid)[0]
+            if "root" != grp.getgrgid(os.stat('/etc/cups/cupsd.conf').st_gid).gr_name:
+                return [grp.getgrgid(os.stat('/etc/cups/cupsd.conf').st_gid).gr_name]
         except OSError:
             return lis
 
@@ -497,7 +497,7 @@ class UserSettings(object): # Note: Deprecated after 2.8.8 in Qt4 (see ui4/ui_ut
         if len(path):
             self.cmd_pcard = 'hp-unload -d %DEVICE_URI%'
         else:
-            self.cmd_pcard = '/usr/local/bin/python2.6 %HOME%/unload.py -d %DEVICE_URI%'
+            self.cmd_pcard = '/usr/local/bin/python2.7 %HOME%/unload.py -d %DEVICE_URI%'
 
         # Copy
         path = which('hp-makecopies')
@@ -505,7 +505,7 @@ class UserSettings(object): # Note: Deprecated after 2.8.8 in Qt4 (see ui4/ui_ut
         if len(path):
             self.cmd_copy = 'hp-makecopies -d %DEVICE_URI%'
         else:
-            self.cmd_copy = '/usr/local/bin/python2.6 %HOME%/makecopies.py -d %DEVICE_URI%'
+            self.cmd_copy = '/usr/local/bin/python2.7 %HOME%/makecopies.py -d %DEVICE_URI%'
 
         # Fax
         path = which('hp-sendfax')
@@ -513,7 +513,7 @@ class UserSettings(object): # Note: Deprecated after 2.8.8 in Qt4 (see ui4/ui_ut
         if len(path):
             self.cmd_fax = 'hp-sendfax -d %FAX_URI%'
         else:
-            self.cmd_fax = '/usr/local/bin/python2.6 %HOME%/sendfax.py -d %FAX_URI%'
+            self.cmd_fax = '/usr/local/bin/python2.7 %HOME%/sendfax.py -d %FAX_URI%'
 
         # Fax Address Book
         path = which('hp-fab')
@@ -521,7 +521,7 @@ class UserSettings(object): # Note: Deprecated after 2.8.8 in Qt4 (see ui4/ui_ut
         if len(path):
             self.cmd_fab = 'hp-fab'
         else:
-            self.cmd_fab = '/usr/local/bin/python2.6 %HOME%/fab.py'
+            self.cmd_fab = '/usr/local/bin/python2.7 %HOME%/fab.py'
 
     def load(self):
         self.loadDefaults()
@@ -1629,6 +1629,28 @@ def su_sudo():
 
     return su_sudo_str
 
+# This function returns the distro name and distro version. 
+#This is provided to check on Fedora 14 in pkit.py file for Plugin-installation.  
+def os_release():
+    os_name = None;
+    os_version = None;
+    if which('lsb_release'):
+       name = os.popen('lsb_release -i | cut -f 2')
+       os_name = name.read().strip()
+       name.close()
+       version = os.popen('lsb_release -r | cut -f 2')
+       os_version=version.read().strip()
+       version.close()
+    else:
+       name = os.popen('cat /etc/issue | cut -c 1-7 | head -n 1')
+       os_name = name.read().strip()
+       name.close()
+       version=os.popen('cat /etc/issue | cut -c 16-17 | head -n 1')
+       os_version=version.read().strip()
+       version.close()
+
+    return os_name,os_version 
+    
 
 #
 # Removes HTML or XML character references and entities from a text string.
