@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 # -*- coding: utf-8 -*-
 #
 # (c) Copyright 2003-2009 Hewlett-Packard Development Company, L.P.
@@ -684,12 +684,12 @@ else: # INTERACTIVE_MODE
             fax_type = mq.get('fax-type', FAX_TYPE_NONE)
 
             if prop.hpcups_build:
-                if fax_type == FAX_TYPE_SOAP:
+                if fax_type == FAX_TYPE_SOAP or fax_type == FAX_TYPE_LEDMSOAP:
                     fax_ppd_name = 'HP-Fax2-hpcups'
                 else:
                     fax_ppd_name = 'HP-Fax-hpcups'
             else: # hpijs
-                if fax_type == FAX_TYPE_SOAP:
+                if fax_type == FAX_TYPE_SOAP or fax_type == FAX_TYPE_LEDMSOAP:
                     fax_ppd_name = 'HP-Fax2-hpijs'
                 else:
                     fax_ppd_name = 'HP-Fax-hpijs'
@@ -893,7 +893,7 @@ else: # INTERACTIVE_MODE
                 if len(path) > 0:
                     cmd = 'hp-testpage %s' % param
                 else:
-                    cmd = '/usr/local/bin/python2.6 ./testpage.py %s' % param
+                    cmd = '/usr/local/bin/python2.7 ./testpage.py %s' % param
 
                 log.debug(cmd)
 
